@@ -24,8 +24,8 @@
 #include <QApplication>
 #include <KLocalizedString>
 #include <QCommandLineParser>
-#include <kdelibs4configmigrator.h>
-#include <kdelibs4migration.h>
+#include <Kdelibs4ConfigMigrator>
+#include <Kdelibs4Migration>
 #include <QStandardPaths>
 #include <QDir>
 #include <KDBusService>
@@ -33,6 +33,8 @@
 
 int main(int argc, char** argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("granatier"));
@@ -56,7 +58,7 @@ int main(int argc, char** argv)
         {
             QDir sourceDir(sourceBasePath + dataDir);
             if(!sourceDir.exists()) continue;
-            QStringList fileNames = sourceDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+            const QStringList fileNames = sourceDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
             QDir().mkpath(targetBasePath + dataDir);
             for(const auto& fileName: fileNames)
             {
@@ -72,7 +74,7 @@ int main(int argc, char** argv)
         KSharedConfig::openConfig()->reparseConfiguration();
     }
 
-    app.setWindowIcon(QIcon::fromTheme(QLatin1String("granatier")));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("granatier")));
     KLocalizedString::setApplicationDomain("granatier");
 
     // About Granatier
